Qwx
===========

**Qwx** minimalist bootloader for node

* With only 2 methods you can up your app
* Concise ~350 lines of code
* No externals dependencies
* Cluster support
* Asynchronous app loading
* Memory optimized
* Bye bye `require` with `../../../`

**Qwx** provide an application mount pipeline, it virtualy mount your files structure as a lasy object.
For example, a file structure like 
    
    /src/
        /models
            A.js
            B.js
            /extras
                /C.js

Can be accessed in node as
```javascript
new models.A()
new models.extras.C()
```
**Don't worry for your memory!** If *B.js* is never called by application, it will never be loaded!

**Qwx** allow to manage your pipeline asynchronouly, so you can wait load config or database connection before you start your app

**Qwx** permit to use cluster mode natively, and you can scale down or scale up your app on demand!


Ok, how to use
============

```javascript
require('qwx')('myApp', { debug: true  }) // You can pass option on construction
    .option('appDir', 'src' )

    .mount('lib')
    .mount('models')
    .mount('controllers')
    .mount('services')

    .mount('custom.path', function( ) {
        return {};
    })
    .run( function( $ ) {
        $();
    })
    .run('services')

;
```



Bundles
=========



Methods
========

## mount( name )
Mount directory structure

## mount( name, handler )
Mount handler at name

## run( handler)
Push to the loading pipeline and run `handler`.
If `handler` signature is like `handler( cb )`, pipeline waiting after callback return.

```javascript
.run(function( cb ) { // Excute function as async function
    setTimeout( function( ) {
        cb();
    },1000)
})
.run(function() { //Execute function as sync function

})
```

## run( mountPoint )
Like `run` execute file at mount point. If mount moint is directory, run will execute all mount point at first level under this directory.

For file structure like
```
    /app
        /services
            /a.js
            /b.js
```
```javascript
.run('services/a') // Execute a
.run('services') // Execute a and b
```

## option( name[, value] )
Get or set option

### appDir
By default to `.`, is the dir where file are located

### mask
Mask to match file or directory
By default `/^[^._]/`, ignore file staring with "." or "_"

### maxDepth
Depth limitation, 15 by default

### debug

### forkRespawn


## options( [ options ] )
Get or set options map

## scale( size )
Scale app to size.
You call set `"full"` to use all machine processors

Clustering
==========
You can isolate action between master and fork ( also called worker ) by prefixing your method by `master` or `fork`

Example:

```javascript
.masterMount( 'myMasterMount' ) // Only mount for master thread
.run(function(){
    // Running action for both
})
.forkRun( function() {
    // Running only on fork
})
```

